@@ -1,20 +1,20 @@
-# Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
+#  Pyrogram - Telegram MTProto API Client Library for Python
+#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
 #
-# This file is part of Pyrogram.
+#  This file is part of Pyrogram.
 #
-# Pyrogram is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published
-# by the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+#  Pyrogram is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU Lesser General Public License as published
+#  by the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-# Pyrogram is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
+#  Pyrogram is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License
-# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
+#  You should have received a copy of the GNU Lesser General Public License
+#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
 from typing import Union
@@ -37,12 +37,10 @@ class EditMessageMedia(BaseClient):
         media: InputMedia,
         reply_markup: "pyrogram.InlineKeyboardMarkup" = None
     ) -> "pyrogram.Message":
-        """Edit audio, document, photo, or video messages.
+        """Edit animation, audio, document, photo or video messages.
 
-        If a message is a part of a message album, then it can be edited only to a photo or a video. Otherwise,
-        message type can be changed arbitrarily. When inline message is edited, new file can't be uploaded.
-        Use previously uploaded file via its file_id or specify a URL. On success, if the edited message was sent
-        by the bot, the edited Message is returned, otherwise True is returned.
+        If a message is a part of a message album, then it can be edited only to a photo or a video. Otherwise, the
+        message type can be changed arbitrarily.
 
         Parameters:
             chat_id (``int`` | ``str``):
@@ -53,7 +51,7 @@ class EditMessageMedia(BaseClient):
             message_id (``int``):
                 Message identifier in the chat specified in chat_id.
 
-            media (:obj:`InputMedia`)
+            media (:obj:`InputMedia`):
                 One of the InputMedia objects describing an animation, audio, document, photo or video.
 
             reply_markup (:obj:`InlineKeyboardMarkup`, *optional*):
@@ -62,11 +60,22 @@ class EditMessageMedia(BaseClient):
         Returns:
             :obj:`Message`: On success, the edited message is returned.
 
-        Raises:
-            RPCError: In case of a Telegram RPC error.
+        Example:
+            .. code-block:: python
+
+                from pyrogram import InputMediaPhoto, InputMediaVideo, InputMediaAudio
+
+                # Replace the current media with a local photo
+                app.edit_message_media(chat_id, message_id, InputMediaPhoto("new_photo.jpg"))
+
+                # Replace the current media with a local video
+                app.edit_message_media(chat_id, message_id, InputMediaVideo("new_video.mp4"))
+
+                # Replace the current media with a local audio
+                app.edit_message_media(chat_id, message_id, InputMediaAudio("new_audio.mp3"))
         """
-        style = self.html if media.parse_mode.lower() == "html" else self.markdown
         caption = media.caption
+        parse_mode = media.parse_mode
 
         if isinstance(media, InputMediaPhoto):
             if os.path.exists(media.media):
@@ -83,7 +92,7 @@ class EditMessageMedia(BaseClient):
                     id=types.InputPhoto(
                         id=media.photo.id,
                         access_hash=media.photo.access_hash,
-                        file_reference=b""
+                        file_reference=media.photo.file_reference
                     )
                 )
             elif media.media.startswith("http"):
@@ -91,9 +100,8 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                media = utils.get_input_media_from_file_id(media.media, 2)
-
-        if isinstance(media, InputMediaVideo):
+                media = utils.get_input_media_from_file_id(media.media, media.file_ref, 2)
+        elif isinstance(media, InputMediaVideo):
             if os.path.exists(media.media):
                 media = self.send(
                     functions.messages.UploadMedia(
@@ -121,7 +129,7 @@ class EditMessageMedia(BaseClient):
                     id=types.InputDocument(
                         id=media.document.id,
                         access_hash=media.document.access_hash,
-                        file_reference=b""
+                        file_reference=media.document.file_reference
                     )
                 )
             elif media.media.startswith("http"):
@@ -129,9 +137,8 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                media = utils.get_input_media_from_file_id(media.media, 4)
-
-        if isinstance(media, InputMediaAudio):
+                media = utils.get_input_media_from_file_id(media.media, media.file_ref, 4)
+        elif isinstance(media, InputMediaAudio):
             if os.path.exists(media.media):
                 media = self.send(
                     functions.messages.UploadMedia(
@@ -158,7 +165,7 @@ class EditMessageMedia(BaseClient):
                     id=types.InputDocument(
                         id=media.document.id,
                         access_hash=media.document.access_hash,
-                        file_reference=b""
+                        file_reference=media.document.file_reference
                     )
                 )
             elif media.media.startswith("http"):
@@ -166,9 +173,8 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                media = utils.get_input_media_from_file_id(media.media, 9)
-
-        if isinstance(media, InputMediaAnimation):
+                media = utils.get_input_media_from_file_id(media.media, media.file_ref, 9)
+        elif isinstance(media, InputMediaAnimation):
             if os.path.exists(media.media):
                 media = self.send(
                     functions.messages.UploadMedia(
@@ -197,7 +203,7 @@ class EditMessageMedia(BaseClient):
                     id=types.InputDocument(
                         id=media.document.id,
                         access_hash=media.document.access_hash,
-                        file_reference=b""
+                        file_reference=media.document.file_reference
                     )
                 )
             elif media.media.startswith("http"):
@@ -205,9 +211,8 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                media = utils.get_input_media_from_file_id(media.media, 10)
-
-        if isinstance(media, InputMediaDocument):
+                media = utils.get_input_media_from_file_id(media.media, media.file_ref, 10)
+        elif isinstance(media, InputMediaDocument):
             if os.path.exists(media.media):
                 media = self.send(
                     functions.messages.UploadMedia(
@@ -229,7 +234,7 @@ class EditMessageMedia(BaseClient):
                     id=types.InputDocument(
                         id=media.document.id,
                         access_hash=media.document.access_hash,
-                        file_reference=b""
+                        file_reference=media.document.file_reference
                     )
                 )
             elif media.media.startswith("http"):
@@ -237,15 +242,15 @@ class EditMessageMedia(BaseClient):
                     url=media.media
                 )
             else:
-                media = utils.get_input_media_from_file_id(media.media, 5)
+                media = utils.get_input_media_from_file_id(media.media, media.file_ref, 5)
 
         r = self.send(
             functions.messages.EditMessage(
                 peer=self.resolve_peer(chat_id),
                 id=message_id,
-                reply_markup=reply_markup.write() if reply_markup else None,
                 media=media,
-                **style.parse(caption)
+                reply_markup=reply_markup.write() if reply_markup else None,
+                **self.parser.parse(caption, parse_mode)
             )
         )
 
